"""Define the CLI related functions and classes."""
from __future__ import annotations

from typing import Optional

import typer

from myco_ai import __version__

app = typer.Typer(help="Myco AI is an assistant for mycologists.")


def version_callback(value: bool) -> None:  # noqa: FBT001
    """Handle the version callback."""
    if value:
        typer.secho(f"myco-ai version: {__version__}", fg=typer.colors.BRIGHT_GREEN, bold=True)
        raise typer.Exit


@app.command()
def main(
    # UP007 ignored here due to: https://github.com/tiangolo/typer/pull/522
    version: Optional[bool] = typer.Option(  # noqa: B008, UP007
        None,
        "--version",
        callback=version_callback,
        is_eager=True,
        help="Display the current Myco AI version",
    ),
) -> None:
    """Run the main python template logic."""
    pass


if __name__ == "__main__":  # pragma: no cover
    app(prog_name="myco-ai")
